from django import template
from django.utils.translation import ugettext_lazy as _

from ..choices import (
    INSTITUTION_TYPES_DICT,
    PRISONER_AGE_CATEGORY_DICT,
    PRISONER_GENDER_DICT,
    PRISONER_TYPES_DICT,
)


register = template.Library()


def translate_jsonfield_values(translation_dict, value_list):
    if value_list:
        return ", ".join(
            str(translation_dict.get(v, _("N/A"))) for v in value_list)
    else:
        return _("N/A")


@register.filter
def translate_institution_types(values):
    return translate_jsonfield_values(INSTITUTION_TYPES_DICT, values)


@register.filter
def translate_prisoner_age_category(values):
    return translate_jsonfield_values(PRISONER_AGE_CATEGORY_DICT, values)


@register.filter
def translate_prisoner_types(values):
    return translate_jsonfield_values(PRISONER_TYPES_DICT, values)


@register.filter
def translate_prisoner_gender(values):
    return translate_jsonfield_values(PRISONER_GENDER_DICT, values)
