from django.test import TestCase

from ..models import (
    ArchiveResource,
    BiblioResource,
    ResourcesGroup,
    Job,
    Statistic,
)
from .factories import (
    ArchiveResourceFactory,
    BiblioResourceFactory,
    GraphFactory,
    JobFactory,
    LinkFactory,
    PersonFactory,
    ResourcesGroupFactory,
    StatisticFactory,
)


class TestManager(TestCase):
    def test_job_manager(self):
        person = PersonFactory()
        job = JobFactory(person=person)

        job = Job.objects.get(pk=job.pk)
        with self.assertNumQueries(0):
            job.person.pk

    def test_resources_group_manager(self):
        resources_group = ResourcesGroupFactory()
        link1 = LinkFactory()
        link2 = LinkFactory()
        resources_group.miscellaneous_urls.add(link1)
        resources_group.miscellaneous_urls.add(link2)

        resources = ResourcesGroup.objects.get(pk=resources_group.pk)
        with self.assertNumQueries(0):
            resources.archive_resource.pk
            resources.bibliography_resource.pk
            resources.crimino_resource.pk
            list([l.title for l in resources.miscellaneous_urls.all()])

    def test_archive_resource_manager(self):
        link1 = LinkFactory()
        link2 = LinkFactory()
        archive_resource = ArchiveResourceFactory()
        archive_resource.other_urls.add(link1)
        archive_resource.other_urls.add(link2)

        archive = ArchiveResource.objects.get(pk=archive_resource.pk)
        with self.assertNumQueries(0):
            list([l.title for l in archive.other_urls.all()])

    def test_biblio_resource_manager(self):
        link1 = LinkFactory()
        link2 = LinkFactory()
        biblio_resource = BiblioResourceFactory()
        biblio_resource.other_urls.add(link1)
        biblio_resource.other_urls.add(link2)

        biblio = BiblioResource.objects.get(pk=biblio_resource.pk)
        with self.assertNumQueries(0):
            list([l.title for l in biblio.other_urls.all()])

    def test_statistic_manager(self):
        graph1 = GraphFactory()
        graph2 = GraphFactory()
        statistic = StatisticFactory()
        statistic.graphs.add(graph1)
        statistic.graphs.add(graph2)

        stats = Statistic.objects.get(pk=statistic.pk)
        with self.assertNumQueries(0):
            list([g.name for g in stats.graphs.all()])
