from datetime import datetime

from django.test import TestCase

from ..choices import LONG_TERM_PRISON, SHORT_TERM_PRISON
from ..models import Institution
from .factories import InstitutionFactory, RoleFactory


class TestM2MInstitutionRole(TestCase):
    @classmethod
    def setUpTestData(self):
        self.institution = InstitutionFactory()
        self.role1 = RoleFactory(
            institution_type=[LONG_TERM_PRISON],
            date_start=datetime(2010, 01, 01))
        self.role2 = RoleFactory(
            institution_type=[SHORT_TERM_PRISON],
            date_start=datetime(2016, 1, 1))

    def test_update_latest_type_from_roles(self):
        self.institution.roles.add(self.role1)
        assert self.institution.latest_type == [LONG_TERM_PRISON]

        self.institution.roles.add(self.role2)
        assert self.institution.latest_type == [SHORT_TERM_PRISON]

        self.institution.roles.remove(self.role2)
        assert self.institution.latest_type == [LONG_TERM_PRISON]

        self.institution.roles.remove(self.role1)
        assert self.institution.latest_type == ["undefined"]

    def test_update_related_institution(self):
        print(self.institution.roles.all())
        self.institution.roles.add(self.role1)
        assert self.institution.latest_type == [LONG_TERM_PRISON]

        self.role1.institution_type = [SHORT_TERM_PRISON]
        self.role1.save()
        institution = Institution.objects.get(pk=self.institution.pk)
        assert institution.latest_type == [SHORT_TERM_PRISON]
